@@ -1,10 +1,6 @@
-use std::mem::size_of_val;
-
-use solana_program::{log::sol_log, sysvar};
-
 use {
     crate::state::*,
-    anchor_lang::{prelude::*, solana_program::system_program, solana_program::instruction::Instruction},
+    anchor_lang::{prelude::*, solana_program::{system_program, instruction::Instruction, sysvar}},
     std::mem::size_of,
 };
 
@@ -33,12 +29,14 @@ pub struct AdminScheduleHealthCheck<'info> {
     pub config: Account<'info, Config>,
 
     #[account(
+        mut,
         seeds = [
             SEED_DAEMON, 
             daemon.owner.as_ref()
         ],
-        bump = bump,
+        bump = daemon.bump,
         constraint = daemon.owner == authority.key(),
+        owner = crate::ID,
     )]
     pub daemon: Account<'info, Daemon>,
 
@@ -75,11 +73,6 @@ pub fn handler(ctx: Context<AdminScheduleHealthCheck>, bump: u8) -> ProgramResul
     let health = &mut ctx.accounts.health;
     let task = &mut ctx.accounts.task;
 
-    // Initialize daemon account.
-    daemon.owner = authority.key();
-    daemon.task_count = 0;
-    daemon.bump = bump;
-
     // Setup the health account.
     let now = clock.unix_timestamp as u64;
     let execute_at = now.checked_add(1).unwrap();
@@ -100,8 +93,6 @@ pub fn handler(ctx: Context<AdminScheduleHealthCheck>, bump: u8) -> ProgramResul
         }
     );
 
-    sol_log(format!("Health_check ix size: {:?}", size_of_val(&health_check_ix)).as_str());
-
     // Initialize task account.
     task.daemon = daemon.key();
     task.id = daemon.task_count;
