@@ -1,5 +1,6 @@
 use anchor_lang::prelude::*;
 use anchor_lang::AccountDeserialize;
+use std::convert::TryFrom;
 
 pub const SEED_CONFIG: &[u8] = b"config";
 
@@ -12,8 +13,9 @@ pub struct Config {
     pub bump: u8,
 }
 
-impl From<Vec<u8>> for Config {
-    fn from(data: Vec<u8>) -> Self {
-        Config::try_deserialize(&mut data.as_slice()).unwrap()
+impl TryFrom<Vec<u8>> for Config {
+    type Error = ProgramError;
+    fn try_from(data: Vec<u8>) -> Result<Self, Self::Error> {
+        Config::try_deserialize(&mut data.as_slice())
     }
 }
